pub struct DvsPaths { /* private fields */ }Expand description
We always need to figure out where the user is in a project, where the root is etc. This struct handles all of it so the rest of the code doesn’t have to
Implementations
Sourceimpl DvsPaths
impl DvsPaths
Sourcepub fn new(
cwd: PathBuf,
repo_root: PathBuf,
metadata_folder_name: impl Into<String>,
) -> Result<Self>
pub fn new( cwd: PathBuf, repo_root: PathBuf, metadata_folder_name: impl Into<String>, ) -> Result<Self>
Create with explicit paths (for testing or R package)
pub fn from_cwd(config: &Config) -> Result<Self>
pub fn metadata_folder(&self) -> PathBuf
pub fn cache_folder(&self) -> PathBuf
pub fn metadata_path(&self, relative: &Path) -> PathBuf
pub fn repo_root(&self) -> &Path
pub fn cwd(&self) -> &Path
Sourcepub fn cwd_relative_to_root(&self) -> Option<&Path>
pub fn cwd_relative_to_root(&self) -> Option<&Path>
Get the path relative from repo root to cwd, or None if at repo root
Sourcepub fn file_path(&self, relative: &Path) -> PathBuf
pub fn file_path(&self, relative: &Path) -> PathBuf
Construct the full file path from a repo-relative path
pub fn validate_for_add( &self, paths: &[PathBuf], ) -> Vec<(PathBuf, AddPathStatus)>
pub fn validate_for_get( &self, paths: &[PathBuf], ) -> Vec<(PathBuf, GetPathStatus)>