pub struct PathFilter { /* private fields */ }Expand description
Which paths to get use for status/get
eg you can pass dir1/ dir2/ and it will expand to dir1/* dir2/*
If recursive is true, then it will expand to dir1//* dir2//*
Implementations
Sourceimpl PathFilter
impl PathFilter
Sourcepub fn cwd_scoped(recursive: bool, dvs_paths: &DvsPaths) -> Self
pub fn cwd_scoped(recursive: bool, dvs_paths: &DvsPaths) -> Self
When a user doesn’t provide a path, we default to the cwd relative to the root