pub struct FileMetadata {
pub hashes: Hashes,
pub size: u64,
pub created_by: String,
pub add_time: Timestamp,
pub compression: Compression,
pub message: Option<String>,
}Expand description
The dvs metadata for a given file
Fields
hashes: Hashessize: u64created_by: Stringadd_time: Timestampcompression: Compressionmessage: Option<String>Implementations
Sourceimpl FileMetadata
impl FileMetadata
pub fn from_hashes( hashes: Hashes, size: u64, compression: Compression, message: Option<String>, ) -> Self
pub fn from_file( path: impl AsRef<Path>, compression: Compression, message: Option<String>, ) -> Result<Self>
Sourcepub fn save(
&self,
operation_id: Uuid,
source_file: impl AsRef<Path>,
backend: &dyn Backend,
paths: &DvsPaths,
relative_path: impl AsRef<Path>,
on_bytes: Option<&(dyn Fn(u64) + Send + Sync)>,
) -> Result<(Outcome, Option<u64>)>
pub fn save( &self, operation_id: Uuid, source_file: impl AsRef<Path>, backend: &dyn Backend, paths: &DvsPaths, relative_path: impl AsRef<Path>, on_bytes: Option<&(dyn Fn(u64) + Send + Sync)>, ) -> Result<(Outcome, Option<u64>)>
Returns whether the file already existed in the dvs folder and therefore is an update and the compressed size if applicable. Copies the source file to storage and saves metadata atomically (both succeed or neither).